@@ -24,8 +24,9 @@ from shapely.ops import polygonize
 
 from adcircpy.figures import figure
 from adcircpy.mesh.parsers import grd, sms2dm
+from adcircpy.utilities import get_logger
 
-_logger = logging.getLogger(__name__)
+LOGGER = get_logger(__name__)
 
 
 class Elements:
@@ -37,7 +38,7 @@ class Elements:
         check_elements: bool = False,
     ):
         if check_elements:
-            _logger.info('validating elements...')
+            LOGGER.info('validating elements...')
             vertex_id_set = nodes.index
             for id, geom in elements.iterrows():
                 if not np.all(np.in1d(geom[1:][~pandas.isna(geom[1:])].values, vertex_id_set)):
@@ -335,7 +336,14 @@ class Rings:
             exterior_polygons.extend(polygon_collection)
             exterior_polygons = collect_interiors(exterior_polygons)
 
-        return MultiPolygon(exterior_polygons)
+        multipolygon = MultiPolygon(exterior_polygons)
+        if not multipolygon.is_valid:
+            try:
+                multipolygon = multipolygon.buffer(0)
+            except Exception as error:
+                logging.exception(error)
+
+        return multipolygon
 
 
 class Grd(ABC):
